==> hasktags-0.73.0-51-x86_64.pkg.tar.zst: usr/share/haskell/register/hasktags.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hasktags
version:              0.73.0
visibility:           public
id:                   hasktags-0.73.0-2hkqmqCvCtBHJNCsJskd0m
key:                  hasktags-0.73.0-2hkqmqCvCtBHJNCsJskd0m
license:              BSD-3-Clause
copyright:            The University Court of the University of Glasgow
maintainer:
    Jack Henahan <jhenahan@me.com>,
    Marc Weber <marco-oweber@gmx.de>,
    Marco Túlio Pimenta Gontijo <marcotmarcot@gmail.com>

author:               The GHC Team
homepage:             http://github.com/MarcWeber/hasktags
synopsis:
    Produces ctags "tags" and etags "TAGS" files for Haskell programs

description:
    Produces ctags "tags" and etags "TAGS" files for Haskell programs.

category:             Development
abi:                  1217ba6870514f24b6f401bce11e4bba
exposed:              True
exposed-modules:      Hasktags
hidden-modules:       Tags DebugShow
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hasktags-0.73.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hasktags-0.73.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hasktags-0.73.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/hasktags
hs-libraries:         HShasktags-0.73.0-2hkqmqCvCtBHJNCsJskd0m
depends:
    base-4.17.2.1 bytestring-0.11.5.3 directory-1.3.7.1
    filepath-1.4.2.2 json-0.10-8JHqCzIaWfgISlRaJQ2tz1
    microlens-platform-0.4.3.5-9cwjW4EtVW79mQyywpFzjQ
    utf8-string-1.0.2-FnO1h94XkEn7naEuvLflUO

haddock-interfaces:   /usr/share/doc/hasktags/html/hasktags.haddock
haddock-html:         /usr/share/doc/hasktags/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> hasktags-0.73.0-56-x86_64.pkg.tar.zst: usr/share/haskell/register/hasktags.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hasktags
version:              0.73.0
visibility:           public
id:                   hasktags-0.73.0-HeXAXQfyBao4DpurBM7DjL
key:                  hasktags-0.73.0-HeXAXQfyBao4DpurBM7DjL
license:              BSD-3-Clause
copyright:            The University Court of the University of Glasgow
maintainer:
    Jack Henahan <jhenahan@me.com>,
    Marc Weber <marco-oweber@gmx.de>,
    Marco Túlio Pimenta Gontijo <marcotmarcot@gmail.com>

author:               The GHC Team
homepage:             http://github.com/MarcWeber/hasktags
synopsis:
    Produces ctags "tags" and etags "TAGS" files for Haskell programs

description:
    Produces ctags "tags" and etags "TAGS" files for Haskell programs.

category:             Development
abi:                  f100652b57587837c7957e3f360c75a7
exposed:              True
exposed-modules:      Hasktags
hidden-modules:       Tags DebugShow
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hasktags-0.73.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hasktags-0.73.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hasktags-0.73.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/hasktags
hs-libraries:         HShasktags-0.73.0-HeXAXQfyBao4DpurBM7DjL
depends:
    base-4.17.2.1 bytestring-0.11.5.3 directory-1.3.7.1
    filepath-1.4.2.2 json-0.10-5oySKNqQNebBaxZiACKOPQ
    microlens-platform-0.4.3.5-7QBwMYbCevH8usIIGYbZPU
    utf8-string-1.0.2-D0oARDqSiCF3CIA0pPBIDm

haddock-interfaces:   /usr/share/doc/hasktags/html/hasktags.haddock
haddock-html:         /usr/share/doc/hasktags/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
